<?php

/**
 * Functions which enhance the theme by hooking into WordPress
 * @package Serifi
 * @since 1.0.0
 */

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}


/* BODY CLASSES
   ==================================================== */
if (!function_exists('serifi_body_classes')) :
	function serifi_body_classes($classes) {

		$serifi_header_layout = esc_attr(get_theme_mod('serifi_header_layout', 'header1'));
		$serifi_blog_layout = esc_attr(get_theme_mod('serifi_blog_layout', 'classic-right'));
		$serifi_single_layout = esc_attr(get_theme_mod('serifi_single_layout', 'classic-right'));

		// Header layout class
		if ($serifi_header_layout !== 'default') {
			$classes[] = 'header-' . $serifi_header_layout;
		}

		// Blog layout class
		if ($serifi_blog_layout !== 'default' && !is_singular()) {
			$classes[] = 'blog-' . $serifi_blog_layout;
		}

		// Single layout class
		if ($serifi_single_layout !== 'default' && is_single()) {
			$classes[] = 'single-' . $serifi_single_layout;
		}

		// Adds a class of hfeed to non-singular pages.
		if (!is_singular()) {
			$classes[] = 'hfeed';
		}

		// Page excerpt class
		if (is_page() && has_excerpt()) {
			$classes[] = 'has-excerpt';
		}

		// Check whether the current page is the default right column template
		if (basename(get_page_template()) === 'page.php') {
			//$classes[] = 'template-right';
		}

		// Check whether the current page is the left column template
		if (is_page_template(array('templates/template-left.php'))) {
			$classes[] = 'template-left';
		}

		// Check whether the current page is the right column template
		if (is_page_template(array('templates/template-full-width.php'))) {
			$classes[] = 'template-full';
		}

		// Check whether the current page is the showcase full width template
		if (is_page_template(array('templates/template-showcase-full.php'))) {
			$classes[] = 'template-showcase-full';
		}
		
		// Check for post thumbnail
		if (
			is_single() && has_post_thumbnail()
			|| is_page() && has_post_thumbnail()
		) {
			$classes[] = 'has-post-thumbnail';
		} else {
			$classes[] = 'no-post-thumbnail';
		}

		// Check whether we're in the customizer preview
		if (is_customize_preview()) {
			$classes[] = 'customizer-preview';
		}

		return $classes;
	}
endif;

add_filter('body_class', 'serifi_body_classes');



/* POST CLASSES
   ==================================================== */
if (!function_exists('serifi_post_class')) :
	function serifi_post_class($classes)
	{

		// If we're not on singular, add a post preview class 
		if (is_home() || is_archive()) {
			$classes[] = 'post-summary';
		}

		if (is_single()) {
			$classes[] = 'full-post';
			$classes[] = 'entry';
		}
		return $classes;
	}
	add_filter('post_class', 'serifi_post_class');
endif;


/* TEMPLATE CONTENT PARTS
   ==================================================== */
function serifi_template_part($template)
{

	// action hook before the content part
	do_action('serifi_before_template_part', $template);

	if (apply_filters('serifi_template_part', true, $template)) {
		if ('archive' === $template || 'index' === $template) {
			get_template_part('template-parts/content', get_post_format());
		}

		if ('page' === $template) {
			get_template_part('template-parts/content', 'page');
		}

		if ('single' === $template) {
			get_template_part('template-parts/content', 'single');
		}

		if ('search' === $template) {
			get_template_part('template-parts/content', 'search');
		}

		if ('404' === $template) {
			get_template_part('template-parts/content', '404');
		}

		if ('none' === $template) {
			get_template_part('template-parts/content', 'none');
		}
	}

	// action hook after the content part
	do_action('serifi_after_template_part', $template);
}




/* ADD MENU CLASSES
   ==================================================== */
function serifi_add_menuclass($ulclass)
{
	return preg_replace('/<a /', '<a class="nav-link"', $ulclass);
}
add_filter('wp_nav_menu', 'serifi_add_menuclass');



/* REMOVE INLINE STYLE SIZES FROM THE FIGURE ELEMENT
   ==================================================== */
add_filter('img_caption_shortcode_width', '__return_false');


/* REMOVE no-js FROM BODY IF JS SUPPORTED
   ==================================================== */
function serifi_supports_js()
{
	echo '<script>document.body.classList.remove("no-js");</script>';
}
add_action('wp_footer', 'serifi_supports_js');


/* CHANGE COMMENT FORM DEFAULT FIELDS
   ==================================================== */

/* Fields wrapper */
function serifi_comment_form_before_fields()
{
	echo '<div class="row no-gutters">';
}
add_action('comment_form_before_fields', 'serifi_comment_form_before_fields');

function serifi_comment_form_after_fields()
{
	echo '</div>';
}
add_action('comment_form_after_fields', 'serifi_comment_form_after_fields');

// Comment fields
function serifi_comment_form_default_fields($fields)
{

	$commenter = wp_get_current_commenter();

	$req      = get_option('require_name_email');
	$aria_req = ($req ? " aria-required='true'" : '');
	$html_req = ($req ? " required='required'" : '');
	$html5    = 'html5';

	$fields['author'] = '
      <p class="comment-form-author col-md-6">
        <input id="author" name="author" type="text" autocomplete="off" placeholder="' . esc_attr__('Name', 'serifi') . ($req ? '*' : '') . '" value="' . esc_attr($commenter['comment_author']) . '" size="30"' . $aria_req . $html_req . ' />
      </p>';

	$fields['email'] = '
      <p class="comment-form-email  col-md-6">
        <input id="email" autocomplete="off" name="email" ' . ($html5 ? 'type="email"' : 'type="text"') . ' placeholder="' . esc_attr__('Email', 'serifi') . ($req ? '*' : '') . '" value="' . esc_attr($commenter['comment_author_email']) . '" size="30" aria-describedby="email-notes"' . $aria_req . $html_req  . ' />
      </p>';

	$fields['url'] = '
      <p class="comment-form-url  col">
        <input id="url" autocomplete="off" name="url" ' . ($html5 ? 'type="url"' : 'type="text"') . ' placeholder="' . esc_attr__('Website', 'serifi') . '" value="' . esc_attr($commenter['comment_author_url']) . '" size="30" />
      </p>';

	return $fields;
}
// Set the comment form fields
add_filter('comment_form_default_fields', 'serifi_comment_form_default_fields', 10, 1);



/* CHANGE THE AVATAR SIZE
   ==================================================== */
function serifi_get_avatar_size()
{
	return 60;
}


/* ADD A TITLE TO POSTS MISSING TITLES
	When a post is missing a title, a default title will be used.
   ==================================================== */
if (!function_exists('serifi_post_title')) {
	function serifi_post_title($title)
	{
		return '' === $title ? esc_html_x('Untitled', 'Added to posts and pages that are missing titles', 'serifi') : $title;
	}
}

add_filter('the_title', 'serifi_post_title');



/* ARCHIVE TITLE PREFIX
	Styles the archive title prefix with a span
   ==================================================== */
function serifi_prefix_archive_title($title)
{

	$regex = apply_filters(
		'serifi_prefix_the_archive_title_regex',
		array(
			'pattern'     => '/(\A[^\:]+\:)/',
			'replacement' => '<span class="archive-prefix colour">$1</span>',
		)
	);

	if (empty($regex)) {
		return $title;
	}
	return preg_replace($regex['pattern'], $regex['replacement'], $title);
}

add_filter('get_the_archive_title', 'serifi_prefix_archive_title');


/* ARCHIVE TITLES
	Change how archive titles are displayed
   ==================================================== */
if (!function_exists('serifi_get_the_archive_title')) :
	function serifi_get_the_archive_title($title)
	{

		$archive_prefix = esc_attr(get_theme_mod('serifi_hide_prefix_archive', 0));

		// If enabled - the prefix archive label is hidden
		if ($archive_prefix) {
			if (is_category()) {
				return single_cat_title('', false);
			} elseif (is_author()) {
				return get_the_author();
			} 
		}
		return $title;
	}
endif;
add_filter('get_the_archive_title', 'serifi_get_the_archive_title');





/* FILTER CLASSES OF WP_LIST_PAGES ITEMS TO MATCH MENU ITEMS
	Filter the class applied to wp_list_pages() items with children to match the menu class, to simplify
	styling of sub levels in the fallback.
   ==================================================== */
if (!function_exists('serifi_filter_wp_list_pages_item_classes')) :
	function serifi_filter_wp_list_pages_item_classes($css_class, $item, $depth, $args, $current_page)
	{

		// Only apply to wp_list_pages() calls with match_menu_classes set to true
		$match_menu_classes = isset($args['match_menu_classes']);

		if (!$match_menu_classes) {
			return $css_class;
		}

		// Add current menu item class
		if (in_array('current_page_item', $css_class)) {
			$css_class[] = 'current-menu-item';
		}

		// Add menu item has children class
		if (in_array('page_item_has_children', $css_class)) {
			$css_class[] = 'menu-item-has-children';
		}

		return $css_class;
	}
	add_filter('page_css_class', 'serifi_filter_wp_list_pages_item_classes', 10, 5);
endif;




/* FILTER THE EXCERPT LENGTH
	Customizable excerpt length
   ==================================================== */
if (!function_exists('serifi_excerpt_length')) {
	function serifi_excerpt_length($length)
	{

		if (is_admin()) {
			return $length;
		}

		$excerpt_length = esc_attr(get_theme_mod('serifi_excerpt_length', '35'));
		return $excerpt_length;
	}
}
add_filter('excerpt_length', 'serifi_excerpt_length', 99);



/* FILTER THE EXCERPT SUFFIX
	Replaces the default [...] with a &hellip; (three dots)
   ==================================================== */
if (!function_exists('serifi_excerpt_more')) :
	function serifi_excerpt_more()
	{
		return '&hellip;';
	}
	add_filter('excerpt_more', 'serifi_excerpt_more');
endif;


/* MOVE READ MORE LINK OUTSIDE OF PARAGRAPHS
	Move the 'continue reading' link outside of paragraph.
   ==================================================== */
if (!function_exists('serifi_move_more_link')) :
	function serifi_move_more_link()
	{
		$serifi_readmore_text = esc_html(get_theme_mod('serifi_readmore_text', esc_html__('Read More', 'serifi')));		
		return '<p><a class="more-link" href="' . esc_url(get_permalink()) . '">' . wp_kses_post($serifi_readmore_text) . '<i class="bi bi-arrow-right"></i></a></p>';
	}
	add_filter('the_content_more_link', 'serifi_move_more_link');
endif;


/* CREATE A CONTINUE READING LINK FOR EXCERPTS
   ==================================================== */
if (!function_exists('serifi_read_more_link')) :
	function serifi_read_more_link()
	{
		$serifi_readmore_text = esc_html(get_theme_mod('serifi_readmore_text', esc_html__('Read More', 'serifi')));
		echo '<p class="more-link-wrapper"><a class="more-link" href="' . esc_url(get_permalink()) . '">' . wp_kses_post($serifi_readmore_text) . '<i class="bi bi-arrow-right"></i></a></p>';
	}
endif;

/* POST HEADER
	This displays the full post header above content
   ==================================================== */
if (!function_exists('serifi_full_post_header')) :
	function serifi_full_post_header()
	{

		echo ' <header class="entry-header">';
		if (esc_attr(get_theme_mod('serifi_hide_post_category', 0))) {
			serifi_featured_cat_labels();
		}

		the_title('<h1 class="entry-title">', '</h1>');

		if (esc_attr(get_theme_mod('serifi_hide_post_entry_meta', 0))) {
			serifi_entry_meta('<div class="entry-meta">', '</div>');
		}
		echo '</header>';
	}
endif;


/* CAN POST THUMBNAIL BE DISPLAYED
	Determines if post thumbnail can be displayed.
   ==================================================== */
function serifi_can_show_post_thumbnail()
{
	return apply_filters(
		'serifi_can_show_post_thumbnail',
		!post_password_required() && !is_attachment() && has_post_thumbnail()
	);
}


/* ADD CONTAINER FOR SUBMENU ICON
	Add a dropdown icon if menu item has children.
   ==================================================== */
function serifi_dropdown_icon_to_menu_link($title, $item, $args, $depth)
{
	if ('primary' === $args->theme_location) {
		foreach ($item->classes as $value) {
			if ('menu-item-has-children' === $value || 'page_item_has_children' === $value) {
				$title = $title . '<span class="submenu-icon"></span>';
			}
		}
	}

	return $title;
}
add_filter('nav_menu_item_title', 'serifi_dropdown_icon_to_menu_link', 10, 4);



/* MODIFY THE WP SEARCH FORM
   ==================================================== */
function search_form($form)
{

	$form = '
      <form method="get" class="search-form" action="' . esc_url(home_url('/')) . '">
        <div class="search-wrap"><label><input type="search" class="search-field" autocomplete="off" placeholder="' . esc_attr_x('Search&hellip;', 'placeholder', 'serifi') . '" value="' . get_search_query() . '" name="s" title="' . esc_attr_x('Search for:', 'title tag', 'serifi') . '" />
          </label><button type="submit" class="search-submit"><i class="bi bi-search"></i></button></div></form>';

	return $form;
}
add_filter('get_search_form', 'search_form');



/* POST COMMENTS
	This sets up the post comments.
   ====================================================*/
if (!function_exists('serifi_post_comments')) :
	function serifi_post_comments()
	{

		// If comments are open or we have at least one comment, load up the comment template.
		if (comments_open() || get_comments_number()) :
			comments_template();
		endif;
	}
endif;

/* POST HEADING
	This sets up the post heading for the title, featured image, etc.
   ====================================================*/
if (!function_exists('serifi_post_header')) :
	function serifi_post_header()
	{

		// Get our post layout to determine what to display
		$serifi_single_layout = get_theme_mod('serifi_single_layout', 'classic-right');

		if (
			$serifi_single_layout === 'center' ||
			$serifi_single_layout === 'classic-left' ||
			$serifi_single_layout === 'classic-right'
		) {

			echo '<header class="entry-header">';
			serifi_featured_cat_labels();
			the_title('<h1 class="entry-title">', '</h1>');
			serifi_entry_meta('<div class="entry-meta">', '</div>');
			echo ' </header>';

			serifi_post_thumbnail();
		}
	}
endif;


/* SITE BRANDING
   ==================================================== */
if (!function_exists('serifi_site_identity')) :
	function serifi_site_identity()
	{

		if (has_custom_logo()) {
			echo '<a class="custom-logo" href="' . esc_url(home_url('/')) . '" rel="home">', the_custom_logo(), '</a>';
		}

		if (esc_attr(get_theme_mod('serifi_show_site_title', 1))) {
			printf(
				'<%1$s id="site-title"><a href="%2$s" rel="home">%3$s</a></%1$s>',
				is_front_page() && is_home() ? 'h1' : 'p',
				esc_url(home_url('/')),
				esc_html(get_bloginfo('name'))
			);
		}
	}
endif;

/* HEADER BRANDING
	This sets up the basic site header branding
   ====================================================*/
if (!function_exists('serifi_header_branding')) :
	function serifi_header_branding()
	{

		$description  = get_bloginfo('description', 'display');

		echo '<div id="site-branding">';

		serifi_site_identity();

		if ($description) {
			if (esc_attr(get_theme_mod('serifi_show_site_desc', 1))) {
				echo '<p id="site-description">' . esc_html($description) . '</p>';
			}
			echo '</div>';
		}
	}
endif;

/* SHOWCASE FULL TEMPLATE IMAGE
	This sets up the featured image as a background.
   ====================================================*/
if ( ! function_exists( 'serifi_showcase_full_image' ) ) : 
function serifi_showcase_full_image() {

	$showcase_header_style   = '';
	$showcase_header_classes = '';
	$showcase_image_url = get_the_post_thumbnail_url( get_the_ID(), 'serifi-showcase-image' ); '';
	
		if ( $showcase_image_url ) {
		$showcase_header_style   = ' style="background-image: url( ' . esc_url( $showcase_image_url ) . ' );"';
		$showcase_header_classes = ' showcase-bg-image';
	}

	if( is_page_template(array('templates/template-showcase-full.php')) && has_post_thumbnail()) {
		echo '<div id="showcase-image" class="' . $showcase_header_classes . '"' . $showcase_header_style . '><div id="showcase-details-wrapper" class="container-fluid"><div id="showcase-details" class="row align-items-end"><div class="col">';
		
		echo '</div></div></div></div>';
	}

	}
endif;

add_action('serifi_after_banner', 'serifi_showcase_full_image');


/* INLINE COLOUR PRESETS
   ====================================================*/
if (!function_exists('serifi_inline_colour_presets')) :
	function serifi_inline_colour_presets()
	{

		$serifi_presets = get_theme_mod('serifi_presets', 'preset1');
		switch (esc_attr($serifi_presets)) {

			case "preset6":
				echo '--serifi-colour-primary: #746382;
						--serifi-colour-secondary: #506075;
						--serifi-colour-tertiary: #506075;	
						--serifi-colour-body-bg: #817a6f;
						--serifi-content-bg-colour: #fffefd;';
				break;

			case "preset5":
				echo '--serifi-colour-primary: #7b9c95;
						--serifi-colour-secondary: #9c614c;
						--serifi-colour-tertiary: #7b9c95;	
						--serifi-colour-body-bg: #37504b;
						--serifi-content-bg-colour: #fffefb;';
				break;

			case "preset4":
				echo '--serifi-colour-primary: #8a8ba0;
						--serifi-colour-secondary: #e1cc6b;
						--serifi-colour-tertiary: #8f885f;	
						--serifi-colour-body-bg: #251e3a;
						--serifi-content-bg-colour: #fffefb;';
				break;

			case "preset3":
				echo '--serifi-colour-primary: #92b2b1;
						--serifi-colour-secondary: #b4ab56;
						--serifi-colour-tertiary: #455d6a;	
						--serifi-colour-body-bg: #f3f4f3;';
				break;

			case "preset2":
				echo '--serifi-colour-primary: #91a2b3;
						--serifi-colour-secondary: #bc946c;
						--serifi-colour-tertiary: #343964;	
						--serifi-colour-body-bg: #f9f9f8;';
				break;

			default:
				echo '--serifi-colour-primary: #818f9e;
						--serifi-colour-secondary: #a6924a;
						--serifi-colour-tertiary: #2d283f;
						--serifi-colour-body-bg: #dfe1df;';
		}
	}
endif;
